@@ -22,7 +22,7 @@
 
 #include "KCardDeck"
 
-#include <KDebug>
+#include <QDebug>
 
 #include <cctype>
 #include <cmath>
@@ -196,7 +196,7 @@ bool Solver::recursive(POSITION *parent)
 #endif
         Total_positions++;
         if ( Total_positions % 10000 == 0 )
-            kDebug() << "positions" << Total_positions;
+            //qDebug() << "positions" << Total_positions;
 
         pos->move = *mp;                 /* struct copy */
         pos->cluster = 0;
@@ -1117,7 +1117,7 @@ POSITION *Solver::new_position(POSITION *parent, MOVE *m)
         }
         if ( Total_positions % 1000 == 1000 )
             print_layout();
-        kDebug() << "new" << dummy;
+        //qDebug() << "new" << dummy;
 #endif
 	p += sizeof(POSITION);
 	return pos;
